@@ -104,33 +104,33 @@ class RedeNeural:
 	def add(x):
 		return x+1
 	def salvar(self,nome,mat):
-	    with open(nome+'.txt', 'w') as arquivo:
-	        for i in range(len(mat)):
-	            for j in range(len(mat[0])):
-	                arquivo.write(str(mat[i][j])+' ')
-	            arquivo.write('\n')
+		with open(nome+'.txt', 'w') as arquivo:
+			for i in range(len(mat)):
+				for j in range(len(mat[0])):
+					arquivo.write(str(mat[i][j])+' ')
+				arquivo.write('\n')
 	def ler(self,nome):
 
-	    arquivo = open(nome+'.txt','r')
+		arquivo = open(nome+'.txt','r')
 
-	    texto = []  #declaro um vetor
-	    matriz = [] #declaro um segundo vetor
-	    texto = arquivo.readlines() #quebra as linhas do arquivo em vetores 
-	    #print("vetor texto -> ",texto) #aqui eu mostro
-	    #print("")
+		texto = []  #declaro um vetor
+		matriz = [] #declaro um segundo vetor
+		texto = arquivo.readlines() #quebra as linhas do arquivo em vetores 
+		#print("vetor texto -> ",texto) #aqui eu mostro
+		#print("")
 
-	    for i in range(len(texto)):          #esse for percorre a posições dp vetor texto
-	        matriz.append(texto[i].split())  #aqui eu quebro nos espasos das palavras
+		for i in range(len(texto)):          #esse for percorre a posições dp vetor texto
+			matriz.append(texto[i].split())  #aqui eu quebro nos espasos das palavras
 
-	    for x in range(len(matriz)):
-	    	for i in range(len(matriz[0])):
-	    		matriz[x][i]=float(matriz[x][i])
-	   			#print(matriz[0][0])
-	    #print("vetor matriz -> ",matriz) #mostra o vertor com um conjunto de vetores
-	    #print("")
-	    #for i in range(len(texto)):          #mostra quedrando em linhas
-	    #    print(matriz[i])  
-	    return matriz
+		for x in range(len(matriz)):
+			for i in range(len(matriz[0])):
+				matriz[x][i]=float(matriz[x][i])
+				#print(matriz[0][0])
+		#print("vetor matriz -> ",matriz) #mostra o vertor com um conjunto de vetores
+		#print("")
+		#for i in range(len(texto)):          #mostra quedrando em linhas
+		#    print(matriz[i])  
+		return matriz
 	def addNeuronio(self,num1,num2):
 		neu=Matriz(num2,num1)
 		neu.aleatorizar()
@@ -241,14 +241,18 @@ class RedeNeural:
 			#print(aux.dado)
 		#print("---------")
 		return aux
-	def open(self,nome='none'):
+	def open(self,nome='arquivo'):
 		for i in range(len(self.neuronios)):
-  			self.neuronios[i].dado=self.rede.ler(nome+str(i))
+			self.neuronios[i].dado=self.ler(nome+str(i))
+		for i in range(len(self.bias)):
+			self.bias[i].dado=self.ler(nome+"_bias"+str(i))
 		
-	def save(self,nome='none'):
+	def save(self,nome='arquivo'):
 		for i in range(len(self.neuronios)):
-  			self.salvar(nome+str(i),self.neuronios[i].dado)
-	    
+			self.salvar(nome+str(i),self.neuronios[i].dado)
+		for i in range(len(self.bias)):
+			self.salvar(nome+"_bias"+str(i),self.bias[i].dado)
+		
 	def treinar(self,entrada,esperado,epoc=10000):
 
 		for i in range(epoc):
